References
==========

Dependencies
------------

* `pandas`_ for fast, flexible, and expressive representations of relational data.
* `requests`_ for HTTP requests to 3rd party APIs.
* `requests-cache`_ for caching HTTP requests to avoid getting throttled by 3rd party API servers.
* `SQLAlchemy`_ for a SQL Python interface.
* `yfinance`_ for historical stock data from Yahoo! Finance.

API References
--------------

* The `BEA API`_ and the `BEA API key registration link`_.
* The `FRED API`_ and the `FRED API key registration link`_.
* The `SEC API`_.

Related Projects
----------------

* `FinRL`_ is a collection of financial reinforcement learning environments and tools.
* `fredapi`_ is an implementation of the FRED API.
* `OpenBBTerminal`_ is an open-source version of the Bloomberg Terminal.
* `sec-edgar`_ is an implementation of a file-based SEC EDGAR parser.
* `sec-edgar-api`_ is an implementation of the SEC EDGAR REST API.

.. _`BEA API`: https://apps.bea.gov/api/signup/
.. _`BEA API key registration link`: https://apps.bea.gov/API/signup/
.. _`FinRL`: https://github.com/AI4Finance-Foundation/FinRL
.. _`FRED API`: https://fred.stlouisfed.org/docs/api/fred/
.. _`FRED API key registration link`: https://fredaccount.stlouisfed.org/login/secure/
.. _`fredapi`: https://github.com/mortada/fredapi
.. _`OpenBBTerminal`: https://github.com/OpenBB-finance/OpenBBTerminal
.. _`pandas`: https://pandas.pydata.org/
.. _`requests`: https://requests.readthedocs.io/en/latest/
.. _`requests-cache`: https://requests-cache.readthedocs.io/en/stable/
.. _`SEC API`: https://www.sec.gov/edgar/sec-api-documentation
.. _`sec-edgar`: https://github.com/sec-edgar/sec-edgar
.. _`sec-edgar-api`: https://github.com/jadchaar/sec-edgar-api
.. _`SQLAlchemy`: https://www.sqlalchemy.org/
.. _`yfinance`: https://github.com/ranaroussi/yfinance
